@@ -171,10 +171,6 @@ class ClBuilderImageAction(Action):
               'method': 'Builder.create_package_list(cl_builder_path,'
                         'cl_builder_image_filename)',
               },
-             {'name': 'create_digest',
-              'message': __("Creating DIGEST for image"),
-              'method': 'Builder.create_digest(cl_builder_image_filename)',
-              },
              {'name': 'umount_system!:mount_system',
               'warning': _("Restore build system resources"),
               'method': 'Builder.mount_target(cl_builder_target)',
