@@ -96,6 +96,9 @@ class DataVarsBuilderLinux(linux.LinuxDataVars):
                     update.VariableClUpdateLastTimestamp(section="update"),
                     update.VariableClUpdateBinhostTimeout(section="update"),
                     update.VariableClUpdateBinhostList(section="update"),
+                    update.VariableClUpdateBinhostUnstableList(section="update"),
+                    update.VariableClUpdateBinhostStableSet(section="update"),
+                    update.VariableClUpdateBinhostStableOptSet(section="update"),
                     update.VariableClUpdateBinhostTimestampPath(
                         section="update"),
                     update.VariableClUpdateBinhostRevisionPath(
@@ -154,6 +157,17 @@ class VariableClBuilderLinuxDatavars(ReadonlyVariable):
         image_fn = self.Get('cl_builder_source_filename')
         return self.get_data(image, image_fn=image_fn, source=True)
 
+    def prepare_vars(self, dvbl):
+        dvbl['cl_update_binhost_recheck_set'] = \
+            self.Get('update.cl_update_binhost_recheck_set')
+        dvbl['cl_update_binhost_stable_opt_set'] = \
+            self.Get('cl_builder_binhost_stable_set')
+        if self.Get('cl_action') not in (
+                Actions.Update, Actions.ChangeProfile) or \
+                not self.GetBool('cl_builder_binhost_scan_set'):
+            dvbl.cache['cl_update_binhost_data'] = [[]]
+        dvbl.prepare_all()
+
     def get_data(self, image, image_fn=None, source=False):
         if image:
             if isinstance(image, distr.ArchiveDistributive):
@@ -162,12 +176,7 @@ class VariableClBuilderLinuxDatavars(ReadonlyVariable):
                 with ignore(DistributiveError):
                     distr_dn = image.getDirectory()
                     dvbl = DataVarsBuilderLinux(systemRoot=distr_dn)
-                    dvbl['cl_update_binhost_recheck_set'] = \
-                        self.Get('update.cl_update_binhost_recheck_set')
-                    if self.Get('cl_action') not in (
-                            Actions.Update, Actions.ChangeProfile):
-                        dvbl.cache['cl_update_binhost_data'] = [[]]
-                    dvbl.prepare_all()
+                    self.prepare_vars(dvbl)
                     return dvbl
         else:
             return ""
